@@ -95,14 +95,15 @@ def arg_parser() -> argparse.ArgumentParser:
         type=str,
         metavar="language",
         help="Generate classes in target language, currently supported: "
-        "python, java, typescript, dotnet",
+        "python, java, typescript, dotnet, cpp, dlang",
     )
 
     parser.add_argument(
         "--codegen-target",
         type=str,
         default=None,
-        help="Defaults to sys.stdout for python and ./ for Java",
+        help="Defaults to sys.stdout for Python/C++/Dlang and ./ for "
+        "Java/TypeScript/.Net",
     )
 
     parser.add_argument(
@@ -110,7 +111,7 @@ def arg_parser() -> argparse.ArgumentParser:
         type=str,
         metavar="directory",
         default=None,
-        help="Directory of example documents for test case generation (Java only).",
+        help="Directory of example documents for test case generation (Java/TypeScript/.Net/Dlang only).",
     )
 
     parser.add_argument(
@@ -119,7 +120,7 @@ def arg_parser() -> argparse.ArgumentParser:
         metavar="dotted.package",
         default=None,
         help="Optional override of the package name which is other derived "
-        "from the base URL (Java only).",
+        "from the base URL (Java/TypeScript/.Net/Dlang only).",
     ),
 
     parser.add_argument(
@@ -135,7 +136,7 @@ def arg_parser() -> argparse.ArgumentParser:
         metavar="parser_info",
         type=str,
         default=None,
-        help="Optional parser name which is accessible via resulted parser API (Python only)",
+        help="Optional parser name which is accessible via resulted parser API (Python and Dlang only)",
     )
 
     exgroup.add_argument(
@@ -265,7 +266,7 @@ def main(argsl: Optional[List[str]] = None) -> int:
         _logger.debug("Index is %s", list(metaschema_loader.idx.keys()))
         _logger.debug("Vocabulary is %s", list(metaschema_loader.vocab.keys()))
         return 1
-    except (RuntimeError) as e:
+    except RuntimeError as e:
         _logger.error(
             "Schema `%s` read error:\n%s",
             args.schema,
