@@ -221,7 +221,7 @@ class PythonCodeGen(CodeGenBase):
         field_hashes = []
         for name in field_names:
             field_eqs.append("self.{0} == other.{0}".format(self.safe_name(name)))
-            field_hashes.append("self.{0}".format(self.safe_name(name)))
+            field_hashes.append(f"self.{self.safe_name(name)}")
         field_eq = " and\n                    ".join(field_eqs)
         field_hash = ",\n            ".join(field_hashes)
         self.out.write(field_inits)
@@ -391,7 +391,6 @@ if _errors__:
     ) -> TypeDef:
         """Parse the given type declaration and declare its components."""
         if isinstance(type_declaration, MutableSequence):
-
             sub_names: List[str] = list(
                 dict.fromkeys([self.type_loader(i).name for i in type_declaration])
             )
@@ -497,7 +496,6 @@ if _errors__:
         optional: bool,
         subscope: str,
     ) -> None:
-
         if self.current_class_is_abstract:
             return
 
