@@ -451,7 +451,7 @@ export enum {enum_name} {{
             for sym in type_declaration["symbols"]:
                 val = self.safe_name(sym)
                 const = self.safe_name(sym).replace("-", "_").replace(".", "_").upper()
-                f.write("""  {const}='{val}',\n""".format(const=const, val=val))
+                f.write(f"""  {const}='{val}',\n""")
             f.write(
                 """}
 """
@@ -734,7 +734,6 @@ export enum {enum_name} {{
         )
 
     def epilogue(self, root_loader: TypeDef) -> None:
-
         """Trigger to generate the epilouge code."""
         pd = "This project contains TypeScript objects and utilities "
         pd = pd + ' auto-generated by <a href=\\"https://github.com/'
@@ -786,7 +785,7 @@ export enum {enum_name} {{
 
         sorted_modules = sorted(self.modules)
         internal_module_exports = "\n".join(
-            "export * from '../{}'".format(f) for f in sorted_modules
+            f"export * from '../{f}'" for f in sorted_modules
         )
 
         example_tests = ""
@@ -845,7 +844,7 @@ export enum {enum_name} {{
                 src = src_template.safe_substitute(template_args)
                 _ensure_directory_and_write(src_path, src)
 
-        for (util_src, util_target) in util_src_dirs.items():
+        for util_src, util_target in util_src_dirs.items():
             copy_utils_recursive(util_src, util_target)
 
     def secondaryfilesdsl_loader(self, inner: TypeDef) -> TypeDef:
